<?php

/**
 * ABSTRACT CLASS
 */
abstract class good_relations_abstract_class implements good_relations_interface {
  protected $bundle;
  protected $mapping_fields = array();
  protected $entity_type;
  protected $entity_bundle;
  protected $entity_mapped_fields = array();

  function __construct($bundle = NULL, $mapping_fields = NULL, $entity_type = NULL, $entity_bundle = NULL, $entity_mapped_fields = NULL) {
    $this->bundle = $bundle;
    $this->mapping_fields = $mapping_fields;
    $this->entity_type = $entity_type;
    $this->entity_bundle = $entity_bundle;
    $this->entity_mapped_fields = $entity_mapped_fields;
  }

  public function resultMessage() {
    return t('The following product type has been mapped: ' . $this->bundle);
  }

  public function setBundle($bundle = NULL) {
    $this->bundle = $bundle;
  }

  public function getBundle() {
    return $this->bundle;
  }

  public function setMappingFields($mapping_fields = NULL) {
    $this->mapping_fields = $mapping_fields;
  }

  public function getMappingFields() {
    return $this->mapping_fields;
  }

  public function setEntityType($entity_type = NULL) {
    $this->entity_type = $entity_type;
  }

  public function getEntityType() {
    return $this->entity_type;
  }

  public function getEntity_bundle() {
    return $this->entity_bundle;
  }

  public function setEntity_bundle($entity_bundle) {
    $this->entity_bundle = $entity_bundle;
  }

  public function setEntityMappedFields($entity_mapped_fields = NULL) {
    $this->entity_mapped_fields = $entity_mapped_fields;
  }

  public function getEntityMappedFields() {
    return $this->entity_mapped_fields;
  }

  /**
   * The RDF MAPPING! (node)
   *
   * @return array
   */
  public function map() {
    $bu = $this->bundle;
    $mf = $this->mapping_fields;

    $rdf_mapping = array();

    // Good Relations offering set up.
    $rdf_mapping = array_merge($rdf_mapping, array('rdf_type' => array('gr:Offering')));
    // The title does not appear a normal field.
    $rdf_mapping = array_merge($rdf_mapping, array('title' => array('predicates' => array('gr:title'))));
    foreach($mf as $id => $value) {
      $rdf_mapping = array_merge($rdf_mapping, array($id => array('predicates' => array($value))));
    }

    $product_mapping = array(
      'type' => 'node',
      'bundle' => $bu,
      'mapping' => $rdf_mapping,
    );

    return $product_mapping;
  }

  /**
   * THE RDF MAPPING! (entity reference)
   *
   * @return array
   */
  public function map_entity() {
    $et = $this->entity_type;
    $eb = $this->entity_bundle;
    $emf = $this->entity_mapped_fields;

    $rdf_mapping = array();

    // Good Relations offering set up.
    $rdf_mapping = array_merge($rdf_mapping, array('rdf_type' => array('gr:Offering')));
    // The title does not appear a normal field.
    $rdf_mapping = array_merge($rdf_mapping, array('title' => array('predicates' => array('gr:title'))));
    foreach ($emf as $id => $value) {
      $rdf_mapping = array_merge($rdf_mapping, array($id => array('predicates' => array($value))));
    }

    $product_mapping = array(
      'type' => $et,
      'bundle' => $eb,
      'mapping' => $rdf_mapping,
    );

    return $product_mapping;
  }

  public function namespaces() {
    return array(
      'gr' => 'http://purl.org/goodrelations/v1#',
      // Google's namespace for their custom vocabularies.
      'v' => 'http://rdf.data-vocabulary.org/#',
    );
  }
}
